@@ -2,7 +2,7 @@
 ## RcppMatrixExample.R: Rcpp R/C++ interface class library RcppMatrix example
 ##
 ## Copyright (C) 2008        Dirk Eddelbuettel
-## Copyright (C) 2009 - 2010 Dirk Eddelbuettel and Romain Francois
+## Copyright (C) 2009 - 2012 Dirk Eddelbuettel and Romain Francois
 ##
 ## This file is part of Rcpp.
 ##
@@ -19,16 +19,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-RcppMatrixExample <- function(mat=matrix(seq(1,9)^2, ncol=3),
-                              api=c("classic", "new")) {
-
-    api <- match.arg(api)               # match to classic or new
-    fun <- paste(api, "RcppMatrixExample", sep="")
-
+RcppMatrixExample <- function(mat=matrix(seq(1,9)^2, ncol=3)) {
     ## Make the call...
-    val <- .Call(fun,                   # either new or classic
-                 mat,
-                 PACKAGE="RcppExamples")
-
+    val <- .Call("newRcppMatrixExample", mat, PACKAGE="RcppExamples")
     val
 }
